@@ -10,35 +10,37 @@ class AirflowTrackingConfig(Config):
 
     spark_submit_dbnd_java_agent = parameter(
         default=None,
-        description="A dbnd java agent jar which used to track a java application, located on the local machine",
+        description="Set the DBND Java agent `jar` which will be "
+        "used to track a Java application, located on the local machine",
     )[str]
 
     databricks_dbnd_java_agent = parameter(
         default=None,
-        description="A dbnd java agent jar which used to track a java application, located on remote machine",
+        description="Set the DBND Java agent `jar` which will be "
+        "used to track a Java application, located on remote machine.",
     )[str]
 
     track_airflow_execute_result = parameter(
         default=False,
-        description="Allow saving the results of tracked airflow operator",
+        description="Enable saving the results of tracked Airflow operators.",
     )[bool]
 
     track_xcom_values = parameter(
         default=False,
-        description="Allow logging the values of xcom variables from airflow",
+        description="Enable logging the values of xcom variables from airflow.",
     )[bool]
 
     max_xcom_length = parameter(
-        default=10, description="The amount of xcom values to track, per operator"
+        default=10, description="Set the number of xcom values to track, per operator."
     )[int]
 
     # This shouldn't be set to None. In webserver None evaluates to True.
     af_with_monitor = parameter(
-        default=True, description="Activate when airflow monitor is not in use"
+        default=True, description="Activate when airflow monitor is not in use."
     )[bool]
 
     sql_reporting = parameter(
-        default=False, description="Enable targets reporting from sql queries"
+        default=False, description="Enable targets reporting from SQL queries."
     )[bool]
 
 
